@@ -5,16 +5,17 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-06-08'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 our $schema = [any => {
     summary => 'String or regex (if string is of the form `/.../`)',
     description => <<'_',
 
-If string is of the form of `/.../`, then it will be parsed as a regex.
-Currently modifiers `i`, `m`, and `s` after the second `/` are allowed.
+Either string or Regexp object is accepted.
 
-Otherwise, it's accepted as a plain string.
+If string is of the form of `/.../`, then it will be compiled into a Regexp
+object. Currently modifiers `i`, `m`, and `s` after the second `/` are allowed.
+If the regex pattern inside `/.../` is invalid, value will be rejected.
 
 _
     of => [
@@ -53,7 +54,7 @@ Sah::Schema::str_or_re - String or regex (if string is of the form `/.../`)
 
 =head1 VERSION
 
-This document describes version 0.006 of Sah::Schema::str_or_re (from Perl distribution Sah-Schemas-Str), released on 2022-06-08.
+This document describes version 0.007 of Sah::Schema::str_or_re (from Perl distribution Sah-Schemas-Str), released on 2022-06-08.
 
 =head1 SYNOPSIS
 
@@ -91,7 +92,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "//";
+ $data = "/foo.*/";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -106,8 +107,8 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "//";
- my $res = $validator->($data); # => ["",qr()]
+ $data = "/foo.*/";
+ my $res = $validator->($data); # => ["",qr(foo.*)]
  
  # a sample invalid data
  $data = "/foo[/";
@@ -176,10 +177,11 @@ L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
 =head1 DESCRIPTION
 
-If string is of the form of C</.../>, then it will be parsed as a regex.
-Currently modifiers C<i>, C<m>, and C<s> after the second C</> are allowed.
+Either string or Regexp object is accepted.
 
-Otherwise, it's accepted as a plain string.
+If string is of the form of C</.../>, then it will be compiled into a Regexp
+object. Currently modifiers C<i>, C<m>, and C<s> after the second C</> are allowed.
+If the regex pattern inside C</.../> is invalid, value will be rejected.
 
 =head1 HOMEPAGE
 
